<?php

/**
 * Currency.php
 *
 * @copyright Copyright © 2017 Ecomm.pro. All rights reserved.
 * @author    dev@ecomm.pro
 */

namespace EcommPro\CustomCurrency\Model\ResourceModel;

use Magento\Eav\Model\Entity\AbstractEntity;
use Magento\Eav\Model\Entity\Context;
use Magento\Store\Model\Store;
use Magento\Store\Model\StoreManagerInterface;
use EcommPro\CustomCurrency\Setup\CurrencySetup;

class Currency extends AbstractEntity
{
    /**
     * Store id
     *
     * @var int
     */
    protected $_storeId = null;

    /**
     * @var StoreManagerInterface
     */
    protected $_storeManager;

    /**
     * Currency constructor.
     * @param Context $context
     * @param StoreManagerInterface $storeManager
     * @param array $data
     */
    public function __construct(
        Context $context,
        StoreManagerInterface $storeManager,
        array $data = []
    ) {
        parent::__construct($context, $data);
        $this->setType(CurrencySetup::ENTITY_TYPE_CODE);
        $this->setConnection(CurrencySetup::ENTITY_TYPE_CODE . '_read', CurrencySetup::ENTITY_TYPE_CODE . '_write');



        $this->_storeManager = $storeManager;
    }

    /**
     * Retrieve employee entity default attributes
     *
     * @return string[]
     */
    protected function _getDefaultAttributes()
    {
        return [
            'created_at',
            'updated_at'
        ];
    }

    /**
     * Set store Id
     *
     * @param integer $storeId
     * @return $this
     */
    public function setStoreId($storeId)
    {
        $this->_storeId = $storeId;
        return $this;
    }

    /**
     * Return store id
     *
     * @return integer
     */
    public function getStoreId()
    {
        if ($this->_storeId === null) {
            return $this->_storeManager->getStore()->getId();
        }
        return $this->_storeId;
    }


    /**
     * Set Attribute values to be saved
     *
     * @param \Magento\Framework\Model\AbstractModel $object
     * @param \Magento\Eav\Model\Entity\Attribute\AbstractAttribute $attribute
     * @param mixed $value
     * @return $this
     */
    protected function _saveAttribute($object, $attribute, $value)
    {
        $table = $attribute->getBackend()->getTable();
        if (!isset($this->_attributeValuesToSave[$table])) {
            $this->_attributeValuesToSave[$table] = [];
        }

        $entityIdField = $attribute->getBackend()->getEntityIdField();
        $storeId = $object->getStoreId()?:Store::DEFAULT_STORE_ID;
        $data = [
            $entityIdField => $object->getId(),
            'attribute_id' => $attribute->getId(),
            'value' => $this->_prepareValueForSave($value, $attribute),
            'store_id' => $storeId,
        ];

        if (!$this->getEntityTable() || $this->getEntityTable() == \Magento\Eav\Model\Entity::DEFAULT_ENTITY_TABLE) {
            $data['entity_type_id'] = $object->getEntityTypeId();
        }

        if ($attribute instanceof \EcommPro\CustomCurrency\Model\ResourceModel\Eav\Attribute) {
            if ($attribute->isScopeStore()) {
                /**
                 * Update attribute value for store
                 */
                $this->_attributeValuesToSave[$table][] = $data;
            } elseif ($attribute->isScopeWebsite() && $storeId != Store::DEFAULT_STORE_ID) {
                /**
                 * Update attribute value for website
                 */
                $storeIds = $this->_storeManager->getStore($storeId)->getWebsite()->getStoreIds(true);
                foreach ($storeIds as $storeId) {
                    $data['store_id'] = (int)$storeId;
                    $this->_attributeValuesToSave[$table][] = $data;
                }
            } else {
                /**
                 * Update global attribute value
                 */
                $data['store_id'] = Store::DEFAULT_STORE_ID;
                $this->_attributeValuesToSave[$table][] = $data;
            }
        } else {
            $data['store_id'] = Store::DEFAULT_STORE_ID;
            $this->_attributeValuesToSave[$table][] = $data;
        }

        return $this;
    }
}
